SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';



-- -----------------------------------------------------
-- Table `Project`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `Project` (
  `Project_ID` INT NOT NULL,
  `Project_Name` VARCHAR(45) NULL,
  PRIMARY KEY (`Project_ID`))
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Cultivar`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `Cultivar` (
  `Cultivar_ID` INT NOT NULL,
  `Cultivar_Name` VARCHAR(45) NULL,
  `Project_Project_ID` INT NOT NULL,
  PRIMARY KEY (`Cultivar_ID`),
  INDEX `fk_Cultivar_Project1_idx` (`Project_Project_ID` ASC),
  CONSTRAINT `fk_Cultivar_Project1`
    FOREIGN KEY (`Project_Project_ID`)
    REFERENCES `Project` (`Project_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `MolecularData`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `MolecularData` (
  `MolecularData_ID` INT NOT NULL,
  `Locus_Name` VARCHAR(45) NULL,
  `Number_Of_Bands` INT NULL,
  `Cultivar_Cultivar_ID` INT NOT NULL,
  `Project_Project_ID` INT NOT NULL,
  PRIMARY KEY (`MolecularData_ID`),
  INDEX `fk_MolecularData_Cultivar1_idx` (`Cultivar_Cultivar_ID` ASC),
  CONSTRAINT `fk_MolecularData_Cultivar1`
    FOREIGN KEY (`Cultivar_Cultivar_ID`)
    REFERENCES `Cultivar` (`Cultivar_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  INDEX `fk_MolecularData_Project1_idx` (`Project_Project_ID` ASC),
  CONSTRAINT `fk_MolecularData_Project1`
    FOREIGN KEY (`Project_Project_ID`)
    REFERENCES `Cultivar` (`Project_Project_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)

ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `Bands`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `Bands` (
  `Band_Number` INT NOT NULL,
  `Band` BINARY NULL,
  `MolecularData_MolecularData_ID` INT NOT NULL,
  `Cultivar_Cultivar_ID` INT NOT NULL,
  `Project_Project_ID` INT NOT NULL,
  PRIMARY KEY (`Band_Number`),
  INDEX `fk_Bands_MolecularData1_idx` (`MolecularData_MolecularData_ID` ASC),
  CONSTRAINT `fk_Bands_MolecularData1`
    FOREIGN KEY (`MolecularData_MolecularData_ID`)
    REFERENCES `MolecularData` (`MolecularData_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  INDEX `fk_Bands_Cultivar1_idx` (`Cultivar_Cultivar_ID` ASC),  
  CONSTRAINT `fk_Bands_Cultivar1`
    FOREIGN KEY (`Cultivar_Cultivar_ID`)
    REFERENCES `MolecularData` (`Cultivar_Cultivar_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  INDEX `fk_Bands_Project1_idx` (`Project_Project_ID` ASC),  
  CONSTRAINT `fk_Bands_Project1`
    FOREIGN KEY (`Project_Project_ID`)
    REFERENCES `MolecularData` (`Project_Project_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)

ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `GeneticData`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `GeneticData` (
  `GeneticData_ID` INT NOT NULL,
  `Locus_Name` VARCHAR(45) NULL,
  `Allele1` INT NULL,
  `Allele2` INT NULL,
  `Cultivar_Cultivar_ID` INT NOT NULL,
  `Project_Project_ID` INT NOT NULL,
  PRIMARY KEY (`GeneticData_ID`),
  INDEX `fk_GeneticData_Cultivar_idx` (`Cultivar_Cultivar_ID` ASC),
  CONSTRAINT `fk_GeneticData_Cultivar`
    FOREIGN KEY (`Cultivar_Cultivar_ID`)
    REFERENCES `Cultivar` (`Cultivar_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  INDEX `fk_GeneticData_Project1_idx` (`Project_Project_ID` ASC),
  CONSTRAINT `fk_GeneticData_Project1`
    FOREIGN KEY (`Project_Project_ID`)
    REFERENCES `Cultivar` (`Project_Project_ID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
